#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
"""
Built-in Constants
==================

A small number of constants live in the built-in namespace.  They are:

"""
"""
The sole value of :attr:`types.NoneType`.  ``None`` is frequently used to
represent the absence of a value, as when default arguments are not passed to a
function.

"""
NotImplemented = None
"""
Special value used in conjunction with extended slicing syntax.


"""
Ellipsis = None
"""
This constant is true if Python was not started with an :option:`-O` option.
See also the :keyword:`assert` statement.


"""
quitcode = None
