# AUTO-GENERATED FILE -- DO NOT EDIT

""" This module is always available. It provides access to mathematical
functions for complex numbers. """

__package__ = None

def acos(x):
  """ acos(x)
  
  Return the arc cosine of x. """
  pass

def acosh(x):
  """ acosh(x)
  
  Return the hyperbolic arccosine of x. """
  pass

def asin(x):
  """ asin(x)
  
  Return the arc sine of x. """
  pass

def asinh(x):
  """ asinh(x)
  
  Return the hyperbolic arc sine of x. """
  pass

def atan(x):
  """ atan(x)
  
  Return the arc tangent of x. """
  pass

def atanh(x):
  """ atanh(x)
  
  Return the hyperbolic arc tangent of x. """
  pass

def cos(x):
  """ cos(x)
  
  Return the cosine of x. """
  pass

def cosh(x):
  """ cosh(x)
  
  Return the hyperbolic cosine of x. """
  pass

e = 2.71828182846

def exp(x):
  """ exp(x)
  
  Return the exponential value e**x. """
  pass

def isinf(z):
  """ isinf(z) -> bool
  Checks if the real or imaginary part of z is infinite. """
  return None

def isnan(z):
  """ isnan(z) -> bool
  Checks if the real or imaginary part of z not a number (NaN) """
  return None

def log(x, base=None):
  """ log(x[, base]) -> the logarithm of x to the given base.
  If the base not specified, returns the natural logarithm (base e) of x. """
  return None

def log10(x):
  """ log10(x)
  
  Return the base-10 logarithm of x. """
  pass

def phase(z):
  """ phase(z) -> float
  
  Return argument, also known as the phase angle, of a complex. """
  return 1.0

pi = 3.14159265359

def polar(z):
  """ polar(z) -> r: float, phi: float
  
  Convert a complex from rectangular coordinates to polar coordinates. r is
  the distance from 0 and phi the phase angle. """
  return 1.0

def rect(r, phi):
  """ rect(r, phi) -> z: complex
  
  Convert from polar coordinates to rectangular coordinates. """
  return None

def sin(x):
  """ sin(x)
  
  Return the sine of x. """
  pass

def sinh(x):
  """ sinh(x)
  
  Return the hyperbolic sine of x. """
  pass

def sqrt(x):
  """ sqrt(x)
  
  Return the square root of x. """
  pass

def tan(x):
  """ tan(x)
  
  Return the tangent of x. """
  pass

def tanh(x):
  """ tanh(x)
  
  Return the hyperbolic tangent of x. """
  pass

